#[repr(C)]
pub enum Key {
Show 136 variants Unknown, Backspace, Tab, Clear, Return, Pause, Escape, Space, ExclamationMark, DoubleQuotes, Hash, Dollar, Ampersand, Quote, LeftParen, RightParen, Asterisk, Plus, Comma, Minus, Period, Slash, Number_0, Number_1, Number_2, Number_3, Number_4, Number_5, Number_6, Number_7, Number_8, Number_9, Colon, Semicolon, Less, Equals, Greater, QuestionMark, At, LeftBracket, Backslash, RightBracket, Caret, Underscore, Backquote, A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S, T, U, V, W, X, Y, Z, Delete, Kp0, Kp1, Kp2, Kp3, Kp4, Kp5, Kp6, Kp7, Kp8, Kp9, KpPeriod, KpDivide, KpMultiply, KpMinus, KpPlus, KpEnter, KpEquals, Up, Down, Right, Left, Insert, Home, End, PageUp, PageDown, F1, F2, F3, F4, F5, F6, F7, F8, F9, F10, F11, F12, F13, F14, F15, Numlock, Capslock, Scrollock, RShift, LShift, RCtrl, LCtrl, RAlt, LAlt, RMeta, LMeta, LSuper, RSuper, Mode, Compose, Help, Print, Sysrq, Break, Menu, Power, Euro, Undo,
}

Variants



Unknown



Backspace



Tab



Clear



Return



Pause



Escape



Space



ExclamationMark



DoubleQuotes



Hash



Dollar



Ampersand



Quote



LeftParen



RightParen



Asterisk



Plus



Comma



Minus



Period



Slash



Number_0



Number_1



Number_2



Number_3



Number_4



Number_5



Number_6



Number_7



Number_8



Number_9



Colon



Semicolon



Less



Equals



Greater



QuestionMark



At



LeftBracket



Backslash



RightBracket



Caret



Underscore



Backquote



A



B



C



D



E



F



G



H



I



J



K



L



M



N



O



P



Q



R



S



T



U



V



W



X



Y



Z



Delete



Kp0



Kp1



Kp2



Kp3



Kp4



Kp5



Kp6



Kp7



Kp8



Kp9



KpPeriod



KpDivide



KpMultiply



KpMinus



KpPlus



KpEnter



KpEquals



Up



Down



Right



Left



Insert



Home



End



PageUp



PageDown



F1



F2



F3



F4



F5



F6



F7



F8



F9



F10



F11



F12



F13



F14



F15



Numlock



Capslock



Scrollock



RShift



LShift



RCtrl



LCtrl



RAlt



LAlt



RMeta



LMeta



LSuper



RSuper



Mode



Compose



Help



Print



Sysrq



Break



Menu



Power



Euro



Undo

Implementations

source

impl Key

source

pub fn from_uint(value: c_uint) -> Option<Self>

source

pub fn to_uint(self) -> c_uint